#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from .common import _copyB, fact

def _tagReplace(soup, args = {}):
	wrap_with_i = [
		soup.find_all("div"),
		soup.find_all("span"),
		soup.find_all("p"),
	]
	for l in wrap_with_i:
		for item in l:
			attrs = str(item.attrs)
			attrs = attrs.replace(": ", ":")
			if 'font-style:italic' in attrs:
				wrapper = fact().new_tag("i")
				wrapper.append(_copyB(item))
				item.replace_with(wrapper)
	wrap_with_p = [
		soup.find_all("div", class_="article-paragraph"),
		soup.find_all("section"),
	]
	for l in wrap_with_p:
		for item in l:
			wrapper = fact().new_tag("p")
			wrapper.append(_copyB(item))
			item.replace_with(wrapper)
	if not args.get('list_replace'):
		to_remove_tags = [
			soup.find_all("li"),
			soup.find_all("ul")
		]
		for l in to_remove_tags:
			for item in l:
				new_item = fact().new_tag("p")
				for x in item.find_all(recursive=False):
					new_item.append(x)
				item.replace_with(new_item)
	return soup


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from .common import _copyB
from bs4 import BeautifulSoup

def _finalTouch(soup, url):
	for item in soup.find_all("footer", class_="author-info"):
		for subitem in item.find_all("a"):
			if subitem.text and "英文版" in subitem.text:
				item.replace_with(subitem)
				break
	if 'pride.com' in url:
		for item in soup.find_all('h2'):
			item.parent.parent.insert(0, _copyB(item))
			item.decompose()
	for item in soup.find_all():
		if item.text == 'Follow TranscendingSelf and support their Fundraiser!':
			item.decompose()
	return soup

def _findFigure(soup, before_content):
	figure = soup.find('figure')
	if figure:
		html = str(soup)
		pre_content = BeautifulSoup(html[:html.find('<figure')], features="html.parser")
		if len(pre_content.text) < 200:
			return figure
	if not before_content:
		return 
	before_content = BeautifulSoup(before_content, features="html.parser")
	figures = before_content.find_all('figure')
	if 'douban' in str(before_content):
		return
	if len(list(figures)) == 1:
		return figures[0]
	if 'telegraph.co.uk' in str(before_content):
		return figures[-1]

def _moveHeadPhoto(soup, before_content):
	figure = _findFigure(soup, before_content)
	if not figure:
		return
	soup.insert(0, _copyB(figure))
	figure.decompose()





#!/usr/bin/env python3
# -*- coding: utf-8 -*-

name = 'readee'

from .article import getArticle

def _formaturl(url):
	if '://' not in url:
		return "https://" + url
	return url

def export(url, content=None, **args):
	article = getArticle(url, content, args)
	if not article.text or not article.text.strip():
		raise Exception('Can not find main content')
	return article